"""Add task_create_partners, task_modify_partners and task_delete_partners.

Revision ID: 41fd1ae225aq
Revises: 31fd1ae8d5bb
Create Date: 2024-07-29 17:11:00.00000

"""

from uuid import uuid4

import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "41fd1ae225aq"
down_revision = "31fd1ae8d5bb"
branch_labels = None
depends_on = None

workflows = [
    {"name": "task_create_partners", "description": "Create partners", "workflow_id": uuid4(), "target": "SYSTEM"},
    {"name": "task_modify_partners", "description": "Modify partners", "workflow_id": uuid4(), "target": "SYSTEM"},
    {"name": "task_delete_partners", "description": "Delete partners", "workflow_id": uuid4(), "target": "SYSTEM"},
]


def upgrade() -> None:
    conn = op.get_bind()
    for workflow in workflows:
        conn.execute(
            sa.text(
                "INSERT INTO workflows VALUES (:workflow_id, :name, :target, :description, now()) ON CONFLICT DO NOTHING"
            ),
            workflow,
        )

    op.alter_column('partners', 'email',
                    existing_type=sa.String(),
                    nullable=False)
    op.drop_column(
        'partners',
        'partner_type'
    )
    op.drop_column(
        'partners',
        'as_number'
    )
    op.drop_column(
        'partners',
        'as_set'
    )
    op.drop_column(
        'partners',
        'route_set'
    )
    op.drop_column(
        'partners',
        'black_listed_as_sets'
    )
    op.drop_column(
        'partners',
        'additional_routers'
    )
    op.drop_column(
        'partners',
        'additional_bgp_speakers'
    )


def downgrade() -> None:
    conn = op.get_bind()
    for workflow in workflows:
        conn.execute(sa.text("DELETE FROM workflows WHERE name = :name"), {"name": workflow["name"]})
